@@ -27,10 +27,12 @@ from covsirphy.cleaning.jhu_complement import JHUDataComplementHandler
 from covsirphy.cleaning.country_data import CountryData
 from covsirphy.cleaning.japan_data import JapanData
 from covsirphy.cleaning.population import PopulationData, Population
+from covsirphy.cleaning.pyramid import PopulationPyramidData
 from covsirphy.cleaning.oxcgrt import OxCGRTData
 from covsirphy.cleaning.pcr_data import PCRData
 from covsirphy.cleaning.covid19datahub import COVID19DataHub
 from covsirphy.cleaning.linelist import LinelistData
+from covsirphy.cleaning.vaccine_data import VaccineData
 from covsirphy.cleaning.dataloader import DataLoader
 # ode
 from covsirphy.ode.mbase import ModelBase
@@ -70,7 +72,8 @@ __all__ = [
     "ODESimulator", "ChangeFinder", "DataHandler",
     "PhaseSeries", "PhaseUnit", "MPEstimator",
     "Term", "CleaningBase", "DataLoader", "COVID19DataHub",
-    "JHUData", "CountryData", "PopulationData", "OxCGRTData",
+    "JHUData", "CountryData", "PopulationData", "OxCGRTData", "VaccineData",
+    "PopulationPyramidData",
     "LinelistData", "PCRData", "JapanData", "JHUDataComplementHandler",
     "ModelBase", "SIR", "SIRD", "SIRF", "SIRFV", "SEWIRF",
     "Estimator", "Trend", "Optimizer",
