@@ -8,9 +8,11 @@ from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.cleaning.japan_data import JapanData
 from covsirphy.cleaning.oxcgrt import OxCGRTData
 from covsirphy.cleaning.population import PopulationData
+from covsirphy.cleaning.pyramid import PopulationPyramidData
 from covsirphy.cleaning.covid19datahub import COVID19DataHub
 from covsirphy.cleaning.linelist import LinelistData
 from covsirphy.cleaning.pcr_data import PCRData
+from covsirphy.cleaning.vaccine_data import VaccineData
 
 
 class DataLoader(Term):
@@ -167,9 +169,6 @@ class DataLoader(Term):
         # Retrieve JHU data from COVID-19 Data Hub
         jhu_data = self._covid19dh(
             name="jhu", basename=basename, verbose=verbose)
-        # Set recovery period for full complement of recovered data in some countries
-        jhu_data.recovery_period = self.linelist(
-            verbose=verbose).recovery_period()
         # Replace Japan dataset with the government-announced data
         japan_data = self.japan()
         jhu_data.replace(japan_data)
@@ -253,14 +252,16 @@ class DataLoader(Term):
                 filename=filename, force=force, verbose=verbose)
         return self._linelist_data
 
-    def pcr(self, basename="covid19dh.csv", local_file=None, verbose=1):
+    def pcr(self, basename="covid19dh.csv", local_file=None,
+            basename_owid="ourworldindata_pcr.csv", verbose=1):
         """
         Load the dataset regarding the number of tests and confirmed cases,
         using local CSV file or COVID-19 Data Hub.
 
         Args:
-            basename (str or None): basename of the file to save the data
+            basename (str or None): basename of the file to save "COVID-19 Data Hub" data
             local_file (str or None): if not None, load the data from this file
+            basename_owid (str): basename of the file to save "Our World In Data" data
             verbose (int): level of verbosity
 
         Notes:
@@ -276,7 +277,43 @@ class DataLoader(Term):
         # Retrieve JHU data from COVID-19 Data Hub
         pcr_data = self._covid19dh(
             name="pcr", basename=basename, verbose=verbose)
+        # Update the values using "Our World In Data" dataset
+        owid_filename = self.dir_path.joinpath(basename_owid)
+        owid_force = self._download_necessity(filename=owid_filename)
+        pcr_data.use_ourworldindata(filename=owid_filename, force=owid_force)
         # Replace Japan dataset with the government-announced data
         japan_data = self.japan()
         pcr_data.replace(japan_data)
         return pcr_data
+
+    def vaccine(self, basename="ourworldindata_vaccine.csv", verbose=1):
+        """
+        Load the dataset regarding vaccination.
+        https://github.com/owid/covid-19-data/tree/master/public/data
+        https://ourworldindata.org/coronavirus
+
+        Args:
+            basename (str): basename of the file to save the data
+            verbose (int): level of verbosity
+
+        Returns:
+            covsirphy.VaccineData: dataset regarding vaccines
+        """
+        filename = self.dir_path.joinpath(basename)
+        force = self._download_necessity(filename=filename)
+        return VaccineData(filename=filename, force=force, verbose=verbose)
+
+    def pyramid(self, basename="wbdata_population_pyramid.csv", verbose=1):
+        """
+        Load the dataset regarding population pyramid.
+        World Bank Group (2020), World Bank Open Data, https://data.worldbank.org/
+
+        Args:
+            basename (str): basename of the file to save the data
+            verbose (int): level of verbosity
+
+        Returns:
+            covsirphy.PopulationPyramidData: dataset regarding population pyramid
+        """
+        filename = self.dir_path.joinpath(basename)
+        return PopulationPyramidData(filename=filename, force=False, verbose=verbose)
