@@ -47,8 +47,8 @@ class PopulationData(CleaningBase):
                     reset index
                 Columns:
                     - ISO3 (str): ISO3 code or "-"
-                    - Country (str): country/region name
-                    - Province (str): province/prefecture/state name
+                    - Country (pandas.Category): country/region name
+                    - Province (pandas.Category): province/prefecture/state name
                     - Date (pd.TimeStamp): date of the records (if available) or today
                     - Population (int): total population
         """
@@ -94,6 +94,8 @@ class PopulationData(CleaningBase):
             :, [self.ISO3, self.COUNTRY, self.PROVINCE, self.DATE, self.N]]
         # Remove duplicates
         df = df.drop_duplicates().reset_index(drop=True)
+        # Update data types to reduce memory
+        df[self.AREA_ABBR_COLS] = df[self.AREA_ABBR_COLS].astype("category")
         return df
 
     def _created_date(self):
