@@ -9,6 +9,7 @@ if not hasattr(sys, "ps1"):
     matplotlib.use("Agg")
 import matplotlib.pyplot as plt
 import numpy as np
+import pandas as pd
 from scipy.optimize import curve_fit, OptimizeWarning
 from covsirphy.cleaning.term import Term
 
@@ -26,6 +27,8 @@ class Trend(Term):
                 - Susceptible (int): the number of susceptible cases
                 - any other columns will be ignored
     """
+    L = "linear"
+    N = "negative_exponential"
 
     def __init__(self, sr_df):
         # Dataset
@@ -35,14 +38,53 @@ class Trend(Term):
         if len(self.sr_df) < 3:
             raise ValueError("The length of @sr_df must be over 2.")
         # Setting for analysis
-        self.result_df = None
+        self._result_df = pd.DataFrame()
+        self.fit_fnc = self.linear
+
+    @property
+    def result_df(self):
+        """
+        pandas.DataFrame: results of fitting
+            Index:
+                - index (Date) (pd.TimeStamp): Observation date
+            Columns:
+                - Recovered: The number of recovered cases
+                - Susceptible_actual: Actual values of Susceptible
+                - columns defined by @columns
+        """
+        if self._result_df.empty:
+            self.run()
+        return self._result_df
 
     def run(self):
         """
-        Perform curve fitting of S-R trend with negative exponential function and save the result.
+        Perform curve fitting with some functions and select the best solution.
+        Then, the result and RMSLE score of the best solution will be saved.
 
         Returns:
-            (pandas.DataFrame): results of fitting
+            covsirphy.Trend: self
+        """
+        L, N = self.L, self.N
+        # Perform fitting and calculate RMSLE scores
+        dataframe_dict = {func: self._run(func=func) for func in (L, N)}
+        score_dict = {
+            func: self._rmsle(fit_df) for (func, fit_df) in dataframe_dict.items()}
+        # Select the best dataframe
+        if 0 < score_dict[L] < score_dict[N] or not score_dict[N]:
+            self._result_df = dataframe_dict[L]
+        else:
+            self._result_df = dataframe_dict[N]
+        return self
+
+    def _run(self, func):
+        """
+        Perform curve fitting of S-R trend with linear or negative exponential function and save the result.
+
+        Args:
+            func (function): the selected curve fitting function, either linear or negative exponential
+
+        Returns:
+            pandas.DataFrame: results of fitting
                 Index:
                     - index (Date) (pd.TimeStamp): Observation date
                 Columns:
@@ -50,13 +92,12 @@ class Trend(Term):
                     - Susceptible_actual: Actual values of Susceptible
                     - columns defined by @columns
         """
-        self.result_df = self._fitting(self.sr_df)
-        return self.result_df
+        self.fit_fnc = self.negative_exp if func == self.N else self.linear
+        return self._fitting(self.sr_df)
 
     def _fitting(self, sr_df):
         """
-        Perform curve fitting of S-R trend
-            with negative exponential function.
+        Perform curve fitting of S-R trend with linear or negative exponential function.
 
         Args:
             sr_df (pandas.DataFrame): training dataset
@@ -67,7 +108,7 @@ class Trend(Term):
                     - Susceptible: Actual data of Susceptible
 
         Returns:
-            (pandas.DataFrame)
+            pandas.DataFrame
                 Index:
                     - index (Date) (pd.TimeStamp): Observation date
                 Columns:
@@ -79,31 +120,54 @@ class Trend(Term):
         df = df.astype(np.float64)
         # Calculate initial values of parameters
         x_series = df[self.R]
-        y_series = df[f"{self.S}{self.A}"]
+        y_series = np.log(df[f"{self.S}{self.A}"]).astype(np.float64)
         a_ini = y_series.max()
         b_ini = y_series.diff().reset_index(drop=True)[1] / a_ini
-        # Curve fitting with negative exponential function
+        # Curve fitting with linear or negative exponential function
         warnings.simplefilter("ignore", OptimizeWarning)
         warnings.simplefilter("ignore", RuntimeWarning)
         param, _ = curve_fit(
-            self.negative_exp, x_series, y_series,
-            p0=[a_ini, b_ini]
+            self.fit_fnc, x_series, y_series,
+            p0=[a_ini, b_ini],
+            # Increase mux number of iteration in curve fitting from 600 (default)
+            maxfev=5000
         )
         # Predict the values with the parameters
         f_partial = functools.partial(
-            self.negative_exp, a=param[0], b=param[1]
+            self.fit_fnc, a=param[0], b=param[1]
         )
-        df[f"{self.S}{self.P}"] = f_partial(x_series)
+        df[f"{self.S}{self.P}"] = np.exp(
+            f_partial(x_series)).astype(np.float64)
         return df.astype(np.int64, errors="ignore")
 
     def rmsle(self):
         """
-        Calculate RMSLE score of actual/predicted Susceptible.
+        Return the best RMSLE score.
 
         Returns:
             (float): RMSLE score
         """
-        df = self.run().replace(np.inf, 0)
+        if self._result_df.empty:
+            self.run()
+        return self._rmsle(self._result_df)
+
+    def _rmsle(self, fit_df):
+        """
+        Calculate RMSLE score of actual/predicted Susceptible.
+
+        Args:
+            fit_df (pandas.DataFrame):
+                Index:
+                    - index (Date) (pd.TimeStamp): Observation date
+                Columns:
+                    - Recovered (int): The number of recovered cases
+                    - Susceptible_actual (int): Actual values of Susceptible
+                    - Susceptible_predicted (int): Predicted values of Susceptible
+
+        Returns:
+            (float): RMSLE score
+        """
+        df = fit_df.replace(np.inf, 0)
         df = df.loc[df[f"{self.S}{self.A}"] > 0, :]
         df = df.loc[df[f"{self.S}{self.P}"] > 0, :]
         actual = df[f"{self.S}{self.A}"]
@@ -122,10 +186,12 @@ class Trend(Term):
             area (str): area name
             filename (str): filename of the figure, or None (display)
         """
-        df = self.run()
+        df = self._result_df.copy()
         df = df.rename({f"{self.S}{self.P}": "Predicted"}, axis=1)
+        # Star/end date
         start_date = self.sr_df.index.min().strftime(self.DATE_FORMAT)
         end_date = self.sr_df.index.max().strftime(self.DATE_FORMAT)
+        # Plotting
         title = f"{area}: S-R trend from {start_date} to {end_date}"
         self.show_with_many(
             result_df=df,
