@@ -7,7 +7,8 @@ import pytest
 import pandas as pd
 from covsirphy import SubsetNotFoundError, PCRIncorrectPreconditionError
 from covsirphy import COVID19DataHub, DataLoader, LinelistData
-from covsirphy import Term, JHUData, CountryData, PopulationData, OxCGRTData, PCRData
+from covsirphy import Term, JHUData, CountryData, PopulationData
+from covsirphy import OxCGRTData, PCRData, VaccineData
 
 
 class TestCOVID19DataHub(object):
@@ -31,7 +32,8 @@ class TestDataLoader(object):
         with pytest.raises(TypeError):
             DataLoader(directory=0)
 
-    def test_dataloader(self, jhu_data, population_data, oxcgrt_data, japan_data, linelist_data):
+    def test_dataloader(self, jhu_data, population_data, oxcgrt_data,
+                        japan_data, linelist_data, pcr_data, vaccine_data):
         # List of primary sources of COVID-19 Data Hub
         data_loader = DataLoader()
         assert data_loader.covid19dh_citation
@@ -41,10 +43,13 @@ class TestDataLoader(object):
         assert isinstance(oxcgrt_data, OxCGRTData)
         assert isinstance(japan_data, CountryData)
         assert isinstance(linelist_data, LinelistData)
+        assert isinstance(pcr_data, PCRData)
+        assert isinstance(vaccine_data, VaccineData)
         # Local file
         data_loader.jhu(local_file="input/covid19dh.csv")
         data_loader.population(local_file="input/covid19dh.csv")
         data_loader.oxcgrt(local_file="input/covid19dh.csv")
+        data_loader.pcr(local_file="input/covid19dh.csv")
 
 
 class TestJHUData(object):
@@ -96,7 +101,9 @@ class TestJHUData(object):
         assert isinstance(jhu_data.countries(complement=True), list)
 
     def test_closing_period(self, jhu_data):
+        warnings.simplefilter("ignore", category=DeprecationWarning)
         assert isinstance(jhu_data.calculate_closing_period(), int)
+        assert isinstance(jhu_data.calculate_recovery_period(), int)
 
     @pytest.mark.parametrize("country", ["UK"])
     def test_subset_complement_non_monotonic(self, jhu_data, country):
@@ -106,11 +113,11 @@ class TestJHUData(object):
 
     @pytest.mark.parametrize("country", ["Netherlands", "China", "Germany"])
     def test_subset_complement_full(self, jhu_data, country):
-        assert isinstance(jhu_data.recovery_period, int)
         if country in set(["Netherlands", "China"]):
             with pytest.raises(ValueError):
                 jhu_data.subset(country=country)
         df, is_complemented = jhu_data.subset_complement(country=country)
+        assert isinstance(jhu_data.recovery_period, int)
         assert set(df.columns) == set(Term.NLOC_COLUMNS)
         assert is_complemented
         with pytest.raises(KeyError):
@@ -222,6 +229,10 @@ class TestPCRData(object):
         df = pcr_data.cleaned()
         assert isinstance(PCRData.from_dataframe(df), PCRData)
 
+    def test_use_ourworldindata(self, pcr_data):
+        pcr_data.use_ourworldindata(
+            filename="input/ourworldindata_pcr.csv")
+
     def test_subset(self, pcr_data):
         with pytest.raises(SubsetNotFoundError):
             pcr_data.subset("Greece", end_date="01Jan2000")
@@ -238,7 +249,7 @@ class TestPCRData(object):
         df, _ = pcr_data.records("Greece")
         assert set(df.columns) == set(PCRData.PCR_NLOC_COLUMNS)
 
-    @pytest.mark.parametrize("country", ["Greece", "Italy"])
+    @pytest.mark.parametrize("country", ["Greece", "Italy", "Sweden"])
     def test_positive_rate(self, pcr_data, country):
         warnings.simplefilter("ignore", category=UserWarning)
         pcr_data.positive_rate(country, show_figure=True)
