@@ -1,16 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from covsirphy.cleaning.japan_data import JapanData
+from covsirphy.util.error import SubsetNotFoundError
 import pytest
 import warnings
 import pandas as pd
 from covsirphy import CleaningBase, SIRF
-from covsirphy import LinelistData, ExampleData
-from covsirphy import Term, CountryData
+from covsirphy import LinelistData, ExampleData, VaccineData
+from covsirphy import Term, CountryData, PopulationPyramidData
 from covsirphy import Word, Population
 
 
 class TestLinelistData(object):
+
+    def test_raw(self, linelist_data):
+        assert isinstance(linelist_data.raw, pd.DataFrame)
+
     def test_linelist(self, linelist_data):
         with pytest.raises(NotImplementedError):
             linelist_data.total()
@@ -116,3 +122,53 @@ class TestCountryData(object):
             province=None)
         df = country_data.cleaned()
         assert set(df.columns) == set(Term.COLUMNS)
+
+    def test_japan_meta(self, japan_data):
+        raw_df = japan_data.meta(cleaned=False)
+        assert isinstance(raw_df, pd.DataFrame)
+        df = japan_data.meta(cleaned=True)
+        assert set(df.columns) == set(JapanData.JAPAN_META_COLS)
+
+
+class TestVaccineData(object):
+    def test_cleaning(self, vaccine_data):
+        df = vaccine_data.cleaned()
+        assert set(VaccineData.VAC_COLS).issubset(df.columns)
+
+    @pytest.mark.parametrize("country", ["Canada"])
+    def test_subset(self, vaccine_data, country):
+        df = vaccine_data.subset(country=country)
+        assert set(df.columns) == set([Term.DATE, Term.VAC])
+        clean_df = vaccine_data.cleaned()
+        df = clean_df.loc[clean_df[Term.COUNTRY] == country, :]
+        product = df.loc[df.index[0], Term.PRODUCT]
+        vaccine_data.subset(
+            country=country, product=product, start_date="15Dec2020", end_date="18Dec2020")
+        with pytest.raises(SubsetNotFoundError):
+            vaccine_data.subset(country=country, end_date="01May2020")
+
+    @pytest.mark.parametrize("country", ["GBR"])
+    def test_records(self, vaccine_data, country):
+        vaccine_data.records(country=country)
+
+    def test_total(self, vaccine_data):
+        df = vaccine_data.total()
+        assert set(df.columns) == set([Term.DATE, Term.VAC])
+
+
+class TestPopulationPyramidData(object):
+    def test_retrieve(self, pyramid_data):
+        df = pyramid_data.retrieve("Japan")
+        assert set(df.columns) == set(PopulationPyramidData.PYRAMID_COLS)
+        with pytest.raises(SubsetNotFoundError):
+            pyramid_data.retrieve("Moon")
+
+    def test_cleaned(self, pyramid_data):
+        df = pyramid_data.cleaned()
+        assert set(df.columns) == set(PopulationPyramidData.PYRAMID_COLS)
+
+    @pytest.mark.parametrize("country", ["Japan"])
+    @pytest.mark.parametrize("sex", [None, "Female", "Male"])
+    def test_records(self, pyramid_data, country, sex):
+        df = pyramid_data.records(country, sex=sex)
+        assert set(df.columns) == set(PopulationPyramidData.SUBSET_COLS)
