@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
+from covsirphy.ode.mbase import ModelBase
 from covsirphy.phase.phase_unit import PhaseUnit
 import warnings
 import pytest
@@ -104,6 +105,9 @@ class TestParamTracker(object):
         with pytest.raises(IndexError):
             tracker.estimate(SIRF, timeout=5, timeout_iteration=5)
 
+    def test_last_model(self, tracker):
+        assert issubclass(tracker.last_model, ModelBase)
+
     def test_simulate(self, tracker):
         tracker.simulate()
 
