@@ -5,7 +5,7 @@ from datetime import datetime
 import warnings
 import pandas as pd
 import pytest
-from covsirphy import ScenarioNotFoundError
+from covsirphy import ScenarioNotFoundError, UnExecutedError
 from covsirphy import Scenario, DataHandler
 from covsirphy import Term, PhaseSeries, SIR, SIRF
 
@@ -46,15 +46,14 @@ class TestDataHandler(object):
         dhl.first_date = "01Apr2020"
         dhl.last_date = "01Aug2020"
         # Test
-        df = dhl.records(show_figure=False)
+        df = dhl.records(variables=None, show_figure=False)
         assert isinstance(df, pd.DataFrame)
-        assert set(df.columns) == set(Term.NLOC_COLUMNS)
+        assert set(df.columns) == set([Term.DATE, Term.CI, Term.F, Term.R])
         dates = df[Term.DATE]
         assert dates.min() == Term.date_obj(dhl.first_date)
         assert dates.max() == Term.date_obj(dhl.last_date)
-        df2 = dhl.records(show_figure=True)
-        assert isinstance(df2, pd.DataFrame)
-        assert set(df2.columns) == set(Term.NLOC_COLUMNS)
+        df2 = dhl.records(variables=["Susceptible"], show_figure=True)
+        assert set(df2.columns) == set([Term.DATE, Term.S])
 
     @pytest.mark.parametrize("country", ["Japan"])
     def test_records_diff(self, jhu_data, population_data, country):
@@ -313,3 +312,22 @@ class TestScenario(object):
         snl.score(past_days=60)
         with pytest.raises(ValueError):
             snl.score(phases=["1st"], past_days=60)
+
+    @pytest.mark.parametrize("country", ["Japan"])
+    def test_fit_predict(self, jhu_data, population_data, oxcgrt_data, country):
+        snl = Scenario(jhu_data, population_data, country)
+        snl.trend(show_figure=False)
+        with pytest.raises(UnExecutedError):
+            snl.fit(oxcgrt_data)
+        snl.estimate(SIRF, timeout=1, timeout_iteration=1)
+        # Fitting
+        with pytest.raises(UnExecutedError):
+            snl.predict()
+        info_dict = snl.fit(oxcgrt_data)
+        assert isinstance(info_dict, dict)
+        # Prediction
+        snl.predict()
+        assert Term.FUTURE in snl.summary()[Term.TENSE].unique()
+        # Fitting & predict
+        snl.fit_predict(oxcgrt_data)
+        assert Term.FUTURE in snl.summary()[Term.TENSE].unique()
